local AnsibleVersions(version="latest", package="ansible") = {
    name: "ansible-" + version,
    image: "python:3.7",
    pull: "always",
    environment: {
      PY_COLORS: 1
    },
    commands: [
      "pip install " + package + " ansible-later~=0.2.0 -qq",
      "git clone https://gitea.rknet.org/ansible/ansible-later-policy.git ~/policy",
      "ansible-later -c ~/policy/config.yml"
    ],
    depends_on: [
      "clone",
    ],
};

local PipelineLinting = {
  kind: "pipeline",
  name: "linting",
  platform: {
    os: "linux",
    arch: "amd64",
  },
  steps: [
    AnsibleVersions(version="latest", package="ansible"),
    AnsibleVersions(version="master", package="git+https://github.com/ansible/ansible.git@devel"),
  ],
  trigger: {
    ref: ["refs/heads/master", "refs/tags/**", "refs/pull/**"],
  },
};

local PipelineNotifications = {
  kind: "pipeline",
  name: "notifications",
  platform: {
    os: "linux",
    arch: "amd64",
  },
  clone: {
    disable: true,
  },
  steps: [
    {
      name: "matrix",
      image: "plugins/matrix",
      settings: {
        homeserver: "https://matrix.rknet.org",
        roomid: "MtidqQXWWAtQcByBhH:rknet.org",
        template: "Status: **{{ build.status }}**<br/> Build: [{{ repo.Owner }}/{{ repo.Name }}]({{ build.link }}) ({{ build.branch }}) by {{ build.author }}<br/> Message: {{ build.message }}",
        username: { "from_secret": "matrix_username" },
        password: { "from_secret": "matrix_password" },
      },
    },
  ],
  depends_on: [
    "linting",
  ],
  trigger: {
    status: [ "success", "failure" ],
    ref: ["refs/heads/master", "refs/tags/**"],
  },
};

[
  PipelineLinting,
  PipelineNotifications,
]
